==> 1.0.2.tar.gz: android/src/main/kotlin/com/wortise/ads/flutter/BannerAdView.kt <==
package com.wortise.ads.flutter

import android.content.Context
import com.wortise.ads.AdError
import com.wortise.ads.AdSize
import com.wortise.ads.banner.BannerAd
import com.wortise.ads.flutter.BannerAd.Companion.CHANNEL_BANNER
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.platform.PlatformView

class BannerAdView(context: Context, viewId: Int, args: Map<*, *>, messenger: BinaryMessenger) : BannerAd.Listener, PlatformView {

    private val adHeight = args["adSize"] as? Int ?: -1

    private val adSize: AdSize
        get() = when {

            (adHeight >= 280) -> AdSize.HEIGHT_280

            (adHeight >= 250) -> AdSize.HEIGHT_250

            (adHeight >= 90)  -> AdSize.HEIGHT_90

            (adHeight >= 50)  -> AdSize.HEIGHT_50

            else -> AdSize.MATCH_VIEW
        }

    private val adUnitId = args["adUnitId"] as String

    private val autoRefreshTime = args["autoRefreshTime"] as? Long ?: 0L

    private val bannerAd: BannerAd

    private val channel = MethodChannel(messenger, "${CHANNEL_BANNER}_$viewId")


    init {
        bannerAd = BannerAd(context).also {
            it.autoRefreshTime = autoRefreshTime
            it.adSize          = adSize
            it.adUnitId        = adUnitId
            it.listener        = this

            it.loadAd()
        }
    }

    override fun dispose() {
        bannerAd.destroy()
    }

    override fun getView() = bannerAd


    override fun onBannerClicked(ad: BannerAd) {
        channel.invokeMethod("clicked", null)
    }

    override fun onBannerFailed(ad: BannerAd, error: AdError) {
        val values = mapOf("error" to error.name)

        channel.invokeMethod("failed", values)
    }

    override fun onBannerLoaded(ad: BannerAd) {
        val values = mapOf(
                "adHeight" to ad.adHeight,
                "adWidth"  to ad.adWidth
        )

        channel.invokeMethod("loaded", values)
    }
}

==> 1.2.3.tar.gz: android/src/main/kotlin/com/wortise/ads/flutter/BannerAdView.kt <==
package com.wortise.ads.flutter

import android.content.Context
import com.wortise.ads.AdError
import com.wortise.ads.AdSize
import com.wortise.ads.banner.BannerAd
import com.wortise.ads.flutter.BannerAd.Companion.CHANNEL_BANNER
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.platform.PlatformView

class BannerAdView(context: Context, viewId: Int, args: Map<*, *>, messenger: BinaryMessenger) : BannerAd.Listener, PlatformView {

    private val adHeight = args["adHeight"] as? Int ?: -1

    private val adSize: AdSize
        get() = when {

            (adHeight >= 280) -> AdSize.HEIGHT_280

            (adHeight >= 250) -> AdSize.HEIGHT_250

            (adHeight >= 90)  -> AdSize.HEIGHT_90

            (adHeight >= 50)  -> AdSize.HEIGHT_50

            else -> AdSize.MATCH_VIEW
        }

    private val adUnitId = args["adUnitId"] as String

    private val autoRefreshTime = args["autoRefreshTime"] as? Long ?: 0L

    private val bannerAd: BannerAd

    private val channel = MethodChannel(messenger, "${CHANNEL_BANNER}_$viewId")


    init {
        bannerAd = BannerAd(context).also {
            it.autoRefreshTime = autoRefreshTime
            it.adSize          = adSize
            it.adUnitId        = adUnitId
            it.listener        = this

            it.loadAd()
        }
    }

    override fun dispose() {
        bannerAd.destroy()
    }

    override fun getView() = bannerAd


    override fun onBannerClicked(ad: BannerAd) {
        channel.invokeMethod("clicked", null)
    }

    override fun onBannerFailed(ad: BannerAd, error: AdError) {
        val values = mapOf("error" to error.name)

        channel.invokeMethod("failed", values)
    }

    override fun onBannerLoaded(ad: BannerAd) {
        val values = mapOf(
                "adHeight" to ad.adHeight,
                "adWidth"  to ad.adWidth
        )

        channel.invokeMethod("loaded", values)
    }
}
